==> 2.4.9.tar.gz: cloudlog/application/language/czech/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Pole deníku';
$lang['account_column1_text'] = 'Vybrat sloupec 1';
$lang['account_column2_text'] = 'Vybrat sloupec 2';
$lang['account_column3_text'] = 'Vybrat sloupec 3';
$lang['account_column4_text'] = 'Vybrat sloupec 4';
$lang['account_column5_text'] = 'Vybrat sloupec 5 (pouze pro deník)';

$lang['account_create_user_account'] = 'Vytvořit uživatelský účet';
$lang['account_edit_account'] = 'Upravit účet';

$lang['account_account_information'] = 'Informace o účtu';
$lang['account_username'] = 'Uživatelské jméno';
$lang['account_email_address'] = 'Emailová adresa';
$lang['account_password'] = 'Heslo';

$lang['account_roles'] = 'Role';
$lang['account_user_role'] = 'Uživatelská role';

$lang['account_theme'] = 'Motiv';
$lang['account_stylesheet'] = 'Styl';

$lang['account_personal_information'] = 'Osobní informace';
$lang['account_first_name'] = 'Jméno';
$lang['account_last_name'] = 'Příjmení';
$lang['account_callsign'] = 'Značka';
$lang['account_gridsquare'] = 'Locátor';


$lang['account_cloudlog_preferences'] = 'Nastavení Cloudlogu';
$lang['account_timezone'] = 'Časové pásmo';
$lang['account_date_format'] = 'Formát data';
$lang['account_measurement_preferences'] = 'Nastavení měření';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Vyberte, jak chcete, aby byla data zobrazena při přihlášení do vašeho účtu.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Vyberte, v jakých jednotkách se budou zobrazovat vzdálenosti.';

$lang['account_main_menu'] = 'Hlavní menu';
$lang['account_show_notes_in_the_main_menu'] = 'Zobrazovat poznámky v hlavním menu.';

$lang['account_main_menu'] = 'Hlavní menu';
$lang['account_show_notes_in_the_main_menu'] = 'Zobrazovat poznámky v hlavním menu.';
$lang['account_gridsquare_and_location_autocomplete'] = 'Automatické doplňování lokátoru a umístění';
$lang['account_location_auto_lookup'] = 'Automatické vyhledávání umístění.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Pokud je nastaveno, lokátor je získán na základě názvu umístění.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Automatické vyhledávání lokátoru a jména pro SOTA vrchol.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Automatické vyhledávání lokátoru a jména pro WWFF referenci.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Automatické vyhledávání lokátoru a jména pro POTA park.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Pokud je nastaveno, jméno a lokátor jsou získány z API a vyplněny do umístění a lokátoru.';

$lang['account_previous_qsl_type'] = 'Předchozí typ QSL';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Vyberte typ QSL k zobrazení v sekci předchozích QSOs.';

$lang['account_qrzcom_hamqthcom_images'] = 'Obrázky qrz.com/hamqth.com';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Zobrazit profilový obrázek partnera z QSO záznamu z profilu qrz.com/hamqth.com v sekci protokolu QSO.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Prosím, nastavte své přihlašovací údaje pro qrz.com/hamqth.com v obecném konfiguračním souboru.';

$lang['account_amsat_status_upload'] = 'Nahrávání stavu AMSAT';
$lang['account_upload_status_of_sat_qsos_to'] = 'Nahrávání stavu SAT QSOs na';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Přihlašovací jméno Logbook of The World (LoTW)';
$lang['account_logbook_of_the_world_lotw_password'] = 'Heslo Logbook of The World (LoTW)';
$lang['account_leave_blank_to_keep_existing_password'] = 'Ponechte prázdné, pokud chcete zachovat stávající heslo';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Email nebo značka volacího znaku Club Logu';
$lang['account_clublog_password'] = 'Heslo Club Logu';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'E-mail nebo značka volacího znaku, kterou používáte pro přihlášení do Club Logu';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'Uživatelské jméno eQSL.cc';
$lang['account_eqslcc_password'] = 'Heslo eQSL.cc';

$lang['account_save_account_changes'] = 'Uložit změny účtu';
$lang['account_create_account'] = 'Vytvořit účet';

$lang['account_delete_user_account'] = 'Smazat uživatelský účet';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Jste si jistí, že chcete smazat uživatelský účet';
$lang['account_yes_delete_this_user'] = 'Ano, smazat tohoto uživatele';
$lang['account_no_do_not_delete_this_user'] = 'Ne, nevymazávat tohoto uživatele';

$lang['account_forgot_password'] = 'Zapomenuté heslo?';
$lang['account_you_can_reset_your_password_here'] = 'Zde si můžete obnovit heslo.';
$lang['account_reset_password'] = 'Obnovit heslo';
$lang['account_the_email_field_is_required'] = 'Pole e-mail je povinné';
$lang['account_confirm_password'] = 'Potvrzení hesla';

$lang['account_forgot_your_password'] = 'Zapomněli jste heslo?';

$lang['account_login_to_cloudlog'] = 'Přihlásit se do Cloudlogu';
$lang['account_login'] = 'Přihlásit se';

$lang['account_mastodon'] = 'Mastodon server';
$lang['account_user_mastodon'] = 'URL Mastodon serveru';

$lang['account_gridmap_settings'] = 'Nastavení pro Mapu lokátorů';
$lang['account_gridmap_default_band'] = 'Výchozí pásma';

==> 2.4.11.tar.gz: cloudlog/application/language/czech/account_lang.php <==
<?php

defined('BASEPATH') OR exit('No direct script access allowed');

$lang['account_logbook_fields'] = 'Pole deníku';
$lang['account_column1_text'] = 'Vybrat sloupec 1';
$lang['account_column2_text'] = 'Vybrat sloupec 2';
$lang['account_column3_text'] = 'Vybrat sloupec 3';
$lang['account_column4_text'] = 'Vybrat sloupec 4';
$lang['account_column5_text'] = 'Vybrat sloupec 5 (pouze pro deník)';

$lang['account_create_user_account'] = 'Vytvořit uživatelský účet';
$lang['account_edit_account'] = 'Upravit účet';

$lang['account_account_information'] = 'Informace o účtu';
$lang['account_username'] = 'Uživatelské jméno';
$lang['account_email_address'] = 'Emailová adresa';
$lang['account_password'] = 'Heslo';

$lang['account_roles'] = 'Role';
$lang['account_user_role'] = 'Uživatelská role';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Motiv';
$lang['account_stylesheet'] = 'Styl';

$lang['account_personal_information'] = 'Osobní informace';
$lang['account_first_name'] = 'Jméno';
$lang['account_last_name'] = 'Příjmení';
$lang['account_callsign'] = 'Značka';
$lang['account_gridsquare'] = 'Locátor';

$lang['account_cloudlog_preferences'] = 'Nastavení Cloudlogu';
$lang['account_timezone'] = 'Časové pásmo';
$lang['account_date_format'] = 'Formát data';
$lang['account_measurement_preferences'] = 'Nastavení měření';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Vyberte, jak chcete, aby byla data zobrazena při přihlášení do vašeho účtu.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Vyberte, v jakých jednotkách se budou zobrazovat vzdálenosti.';
$lang['account_cloudlog_language'] = 'Cloudlog Language';
$lang['account_choose_cloudlog_language'] = 'Choose Cloudlog language.';

$lang['account_main_menu'] = 'Hlavní menu';
$lang['account_show_notes_in_the_main_menu'] = 'Zobrazovat poznámky v hlavním menu.';

$lang['account_gridsquare_and_location_autocomplete'] = 'Automatické doplňování lokátoru a umístění';
$lang['account_location_auto_lookup'] = 'Automatické vyhledávání umístění.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Pokud je nastaveno, lokátor je získán na základě názvu umístění.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Automatické vyhledávání lokátoru a jména pro SOTA vrchol.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Automatické vyhledávání lokátoru a jména pro WWFF referenci.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Automatické vyhledávání lokátoru a jména pro POTA park.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Pokud je nastaveno, jméno a lokátor jsou získány z API a vyplněny do umístění a lokátoru.';

$lang['account_previous_qsl_type'] = 'Předchozí typ QSL';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Vyberte typ QSL k zobrazení v sekci předchozích QSOs.';

$lang['account_qrzcom_hamqthcom_images'] = 'Obrázky qrz.com/hamqth.com';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Zobrazit profilový obrázek partnera z QSO záznamu z profilu qrz.com/hamqth.com v sekci protokolu QSO.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Prosím, nastavte své přihlašovací údaje pro qrz.com/hamqth.com v obecném konfiguračním souboru.';

$lang['account_amsat_status_upload'] = 'Nahrávání stavu AMSAT';
$lang['account_upload_status_of_sat_qsos_to'] = 'Nahrávání stavu SAT QSOs na';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Přihlašovací jméno Logbook of The World (LoTW)';
$lang['account_logbook_of_the_world_lotw_password'] = 'Heslo Logbook of The World (LoTW)';
$lang['account_leave_blank_to_keep_existing_password'] = 'Ponechte prázdné, pokud chcete zachovat stávající heslo';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Email nebo značka volacího znaku Club Logu';
$lang['account_clublog_password'] = 'Heslo Club Logu';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'E-mail nebo značka volacího znaku, kterou používáte pro přihlášení do Club Logu';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'Uživatelské jméno eQSL.cc';
$lang['account_eqslcc_password'] = 'Heslo eQSL.cc';

$lang['account_save_account_changes'] = 'Uložit změny účtu';
$lang['account_create_account'] = 'Vytvořit účet';

$lang['account_delete_user_account'] = 'Smazat uživatelský účet';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Jste si jistí, že chcete smazat uživatelský účet';
$lang['account_yes_delete_this_user'] = 'Ano, smazat tohoto uživatele';
$lang['account_no_do_not_delete_this_user'] = 'Ne, nevymazávat tohoto uživatele';

$lang['account_forgot_password'] = 'Zapomenuté heslo?';
$lang['account_you_can_reset_your_password_here'] = 'Zde si můžete obnovit heslo.';
$lang['account_reset_password'] = 'Obnovit heslo';
$lang['account_the_email_field_is_required'] = 'Pole e-mail je povinné';
$lang['account_confirm_password'] = 'Potvrzení hesla';

$lang['account_forgot_your_password'] = 'Zapomněli jste heslo?';

$lang['account_login_to_cloudlog'] = 'Přihlásit se do Cloudlogu';
$lang['account_login'] = 'Přihlásit se';

$lang['account_mastodon'] = 'Mastodon server';
$lang['account_user_mastodon'] = 'URL Mastodon serveru';
$lang['account_user_mastodon_hint'] = "Main URL of your Mastodon server, e.g. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Settings for Default Band and Confirmation';
$lang['account_gridmap_default_band'] = 'Výchozí pásma';
$lang['account_qsl_settings'] = 'Default QSL-Methods';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Winkeyer support in Cloudlog is very experimental read the wiki first at <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> before enabling.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Enabled";
